@@ -350,6 +350,7 @@ class KalturaDailymotionDistributionProfile(KalturaConfigurableDistributionProfi
             recommendedDcForDownload=NotImplemented,
             recommendedDcForExecute=NotImplemented,
             distributeTrigger=NotImplemented,
+            supportImageEntry=NotImplemented,
             fieldConfigArray=NotImplemented,
             itemXpathsToExtend=NotImplemented,
             useCategoryEntries=NotImplemented,
@@ -382,6 +383,7 @@ class KalturaDailymotionDistributionProfile(KalturaConfigurableDistributionProfi
             recommendedDcForDownload,
             recommendedDcForExecute,
             distributeTrigger,
+            supportImageEntry,
             fieldConfigArray,
             itemXpathsToExtend,
             useCategoryEntries)
