@@ -287,6 +287,7 @@ class KalturaFacebookDistributionProfile(KalturaConfigurableDistributionProfile)
             recommendedDcForDownload=NotImplemented,
             recommendedDcForExecute=NotImplemented,
             distributeTrigger=NotImplemented,
+            supportImageEntry=NotImplemented,
             fieldConfigArray=NotImplemented,
             itemXpathsToExtend=NotImplemented,
             useCategoryEntries=NotImplemented,
@@ -323,6 +324,7 @@ class KalturaFacebookDistributionProfile(KalturaConfigurableDistributionProfile)
             recommendedDcForDownload,
             recommendedDcForExecute,
             distributeTrigger,
+            supportImageEntry,
             fieldConfigArray,
             itemXpathsToExtend,
             useCategoryEntries)
