@@ -183,6 +183,7 @@ class KalturaMetroPcsDistributionProfile(KalturaConfigurableDistributionProfile)
             recommendedDcForDownload=NotImplemented,
             recommendedDcForExecute=NotImplemented,
             distributeTrigger=NotImplemented,
+            supportImageEntry=NotImplemented,
             fieldConfigArray=NotImplemented,
             itemXpathsToExtend=NotImplemented,
             useCategoryEntries=NotImplemented,
@@ -222,6 +223,7 @@ class KalturaMetroPcsDistributionProfile(KalturaConfigurableDistributionProfile)
             recommendedDcForDownload,
             recommendedDcForExecute,
             distributeTrigger,
+            supportImageEntry,
             fieldConfigArray,
             itemXpathsToExtend,
             useCategoryEntries)
