@@ -195,6 +195,7 @@ class KalturaQuickPlayDistributionProfile(KalturaConfigurableDistributionProfile
             recommendedDcForDownload=NotImplemented,
             recommendedDcForExecute=NotImplemented,
             distributeTrigger=NotImplemented,
+            supportImageEntry=NotImplemented,
             fieldConfigArray=NotImplemented,
             itemXpathsToExtend=NotImplemented,
             useCategoryEntries=NotImplemented,
@@ -241,6 +242,7 @@ class KalturaQuickPlayDistributionProfile(KalturaConfigurableDistributionProfile
             recommendedDcForDownload,
             recommendedDcForExecute,
             distributeTrigger,
+            supportImageEntry,
             fieldConfigArray,
             itemXpathsToExtend,
             useCategoryEntries)
