@@ -5,10 +5,10 @@
 #                          |_|\_\__,_|_|\__|\_,_|_| \__,_|
 #
 # This file is part of the Kaltura Collaborative Media Suite which allows users
-# to do with audio, video, and animation what Wiki platfroms allow them to do with
+# to do with audio, video, and animation what Wiki platforms allow them to do with
 # text.
 #
-# Copyright (C) 2006-2020  Kaltura Inc.
+# Copyright (C) 2006-2021  Kaltura Inc.
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as
@@ -44,6 +44,19 @@ from ..Base import (
 )
 
 ########## enums ##########
+# @package Kaltura
+# @subpackage Client
+class KalturaSipSourceType(object):
+    PICTURE_IN_PICTURE = 1
+    TALKING_HEADS = 2
+    SCREEN_SHARE = 3
+
+    def __init__(self, value):
+        self.value = value
+
+    def getValue(self):
+        return self.value
+
 # @package Kaltura
 # @subpackage Client
 class KalturaSipServerNodeOrderBy(object):
@@ -450,10 +463,11 @@ class KalturaPexipService(KalturaServiceBase):
     def __init__(self, client = None):
         KalturaServiceBase.__init__(self, client)
 
-    def generateSipUrl(self, entryId, regenerate = False):
+    def generateSipUrl(self, entryId, regenerate = False, sourceType = 1):
         kparams = KalturaParams()
         kparams.addStringIfDefined("entryId", entryId)
         kparams.addBoolIfDefined("regenerate", regenerate);
+        kparams.addIntIfDefined("sourceType", sourceType);
         self.client.queueServiceActionCall("sip_pexip", "generateSipUrl", "None", kparams)
         if self.client.isMultiRequest():
             return self.client.getMultiRequestResult()
@@ -466,7 +480,6 @@ class KalturaPexipService(KalturaServiceBase):
         if self.client.isMultiRequest():
             return self.client.getMultiRequestResult()
         resultNode = self.client.doQueue()
-        return getXmlNodeBool(resultNode)
 
     def listRooms(self, offset = 0, pageSize = 500, activeOnly = False):
         kparams = KalturaParams()
@@ -499,6 +512,7 @@ class KalturaSipClientPlugin(KalturaClientPlugin):
 
     def getEnums(self):
         return {
+            'KalturaSipSourceType': KalturaSipSourceType,
             'KalturaSipServerNodeOrderBy': KalturaSipServerNodeOrderBy,
         }
 
