@@ -5,10 +5,10 @@
 #                          |_|\_\__,_|_|\__|\_,_|_| \__,_|
 #
 # This file is part of the Kaltura Collaborative Media Suite which allows users
-# to do with audio, video, and animation what Wiki platfroms allow them to do with
+# to do with audio, video, and animation what Wiki platforms allow them to do with
 # text.
 #
-# Copyright (C) 2006-2020  Kaltura Inc.
+# Copyright (C) 2006-2021  Kaltura Inc.
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as
@@ -105,6 +105,7 @@ class KalturaWebexDropFolder(KalturaDropFolder):
             path=NotImplemented,
             fileSizeCheckInterval=NotImplemented,
             fileDeletePolicy=NotImplemented,
+            fileDeleteRegex=NotImplemented,
             autoFileDeleteDays=NotImplemented,
             fileHandlerType=NotImplemented,
             fileNamePatterns=NotImplemented,
@@ -144,6 +145,7 @@ class KalturaWebexDropFolder(KalturaDropFolder):
             path,
             fileSizeCheckInterval,
             fileDeletePolicy,
+            fileDeleteRegex,
             autoFileDeleteDays,
             fileHandlerType,
             fileNamePatterns,
