@@ -5,10 +5,10 @@
 #                          |_|\_\__,_|_|\__|\_,_|_| \__,_|
 #
 # This file is part of the Kaltura Collaborative Media Suite which allows users
-# to do with audio, video, and animation what Wiki platfroms allow them to do with
+# to do with audio, video, and animation what Wiki platforms allow them to do with
 # text.
 #
-# Copyright (C) 2006-2020  Kaltura Inc.
+# Copyright (C) 2006-2021  Kaltura Inc.
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as
@@ -309,6 +309,7 @@ class KalturaWidevineFlavorAsset(KalturaFlavorAsset):
             partnerData=NotImplemented,
             partnerDescription=NotImplemented,
             actualSourceAssetParamsIds=NotImplemented,
+            sizeInBytes=NotImplemented,
             flavorParamsId=NotImplemented,
             width=NotImplemented,
             height=NotImplemented,
@@ -340,6 +341,7 @@ class KalturaWidevineFlavorAsset(KalturaFlavorAsset):
             partnerData,
             partnerDescription,
             actualSourceAssetParamsIds,
+            sizeInBytes,
             flavorParamsId,
             width,
             height,
